@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2007-2009 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -62,6 +62,12 @@ enum {
 	LAST_SIGNAL
 };
 
+typedef enum {
+	EGG_IDLETIME_ALARM_TYPE_POSITIVE,
+	EGG_IDLETIME_ALARM_TYPE_NEGATIVE,
+	EGG_IDLETIME_ALARM_TYPE_DISABLED
+} EggIdletimeAlarmType;
+
 static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer egg_idletime_object = NULL;
 
@@ -69,20 +75,26 @@ G_DEFINE_TYPE (EggIdletime, egg_idletime, G_TYPE_OBJECT)
 
 /**
  * egg_idletime_xsync_alarm_set:
- *
- * Gets the time remaining for the current percentage
- *
  */
 static void
-egg_idletime_xsync_alarm_set (EggIdletime *idletime, EggIdletimeAlarm *alarm, gboolean positive)
+egg_idletime_xsync_alarm_set (EggIdletime *idletime, EggIdletimeAlarm *alarm, EggIdletimeAlarmType alarm_type)
 {
 	XSyncAlarmAttributes attr;
 	XSyncValue delta;
 	unsigned int flags;
 	XSyncTestType test;
 
+	/* just remove it */
+	if (alarm_type == EGG_IDLETIME_ALARM_TYPE_DISABLED) {
+		if (alarm->xalarm) {
+			XSyncDestroyAlarm (idletime->priv->dpy, alarm->xalarm);
+			alarm->xalarm = None;
+		}
+		return;
+	}
+
 	/* which way do we do the test? */
-	if (positive)
+	if (alarm_type == EGG_IDLETIME_ALARM_TYPE_POSITIVE)
 		test = XSyncPositiveTransition;
 	else
 		test = XSyncNegativeTransition;
@@ -112,43 +124,25 @@ egg_idletime_alarm_reset_all (EggIdletime *idletime)
 	guint i;
 	EggIdletimeAlarm *alarm;
 
+	g_return_if_fail (EGG_IS_IDLETIME (idletime));
+
 	/* reset all the alarms (except the reset alarm) to their timeouts */
 	for (i=1; i<idletime->priv->array->len; i++) {
 		alarm = g_ptr_array_index (idletime->priv->array, i);
-		egg_idletime_xsync_alarm_set (idletime, alarm, TRUE);
+		egg_idletime_xsync_alarm_set (idletime, alarm, EGG_IDLETIME_ALARM_TYPE_POSITIVE);
 	}
 
-	/* emit signal */
+	/* set the reset alarm to be disabled */
+	alarm = g_ptr_array_index (idletime->priv->array, 0);
+	egg_idletime_xsync_alarm_set (idletime, alarm, EGG_IDLETIME_ALARM_TYPE_DISABLED);
+
+	/* emit signal so say we've reset all timers */
 	g_signal_emit (idletime, signals [SIGNAL_RESET], 0);
 
 	/* we need to be reset again on the next event */
 	idletime->priv->reset_set = FALSE;
 }
 
-/**
- * egg_idletime_timeout:
- */
-static void
-egg_idletime_timeout (EggIdletime *idletime, EggIdletimeAlarm *alarm)
-{
-	/* emit signal */
-	g_signal_emit (idletime, signals [SIGNAL_ALARM_EXPIRED], 0, alarm->id);
-}
-
-/**
- * egg_idletime_xsync_value_add_one:
- *
- * Just adds one to a XSyncValue. I love X.
- */
-static void
-egg_idletime_xsync_value_add_one (XSyncValue *from, XSyncValue *to)
-{
-	int overflow;
-	XSyncValue add;
-	XSyncIntToValue (&add, -1);
-	XSyncValueAdd (to, *from, add, &overflow);
-}
-
 /**
  * egg_idletime_alarm_find_id:
  */
@@ -166,25 +160,28 @@ egg_idletime_alarm_find_id (EggIdletime *idletime, guint id)
 }
 
 /**
- * egg_idletime_x_set_reset:
+ * egg_idletime_set_reset_alarm:
  */
 static void
-egg_idletime_x_set_reset (EggIdletime *idletime, XSyncAlarmNotifyEvent *alarm_event)
+egg_idletime_set_reset_alarm (EggIdletime *idletime, XSyncAlarmNotifyEvent *alarm_event)
 {
 	EggIdletimeAlarm *alarm;
+	int overflow;
+	XSyncValue add;
 
 	alarm = egg_idletime_alarm_find_id (idletime, 0);
 
-	if (idletime->priv->reset_set == FALSE) {
+	if (!idletime->priv->reset_set) {
 		/* don't match on the current value because
 		 * XSyncNegativeComparison means less or equal. */
-		egg_idletime_xsync_value_add_one (&alarm_event->counter_value, &alarm->timeout);
+		XSyncIntToValue (&add, -1);
+		XSyncValueAdd (&alarm->timeout, alarm_event->counter_value, add, &overflow);
 
 		/* set the reset alarm to fire the next time
 		 * idletime->priv->idle_counter < the current counter value */
-		egg_idletime_xsync_alarm_set (idletime, alarm, FALSE);
+		egg_idletime_xsync_alarm_set (idletime, alarm, EGG_IDLETIME_ALARM_TYPE_NEGATIVE);
 
-		/* don't try to set this again */
+		/* don't try to set this again if multiple timers are doing off in sequence */
 		idletime->priv->reset_set = TRUE;
 	}
 }
@@ -206,10 +203,10 @@ egg_idletime_alarm_find_event (EggIdletime *idletime, XSyncAlarmNotifyEvent *ala
 }
 
 /**
- * egg_idletime_x_event_filter:
+ * egg_idletime_event_filter_cb:
  */
 static GdkFilterReturn
-egg_idletime_x_event_filter (GdkXEvent *gdkxevent, GdkEvent *event, gpointer data)
+egg_idletime_event_filter_cb (GdkXEvent *gdkxevent, GdkEvent *event, gpointer data)
 {
 	EggIdletimeAlarm *alarm;
 	XEvent *xevent = (XEvent *) gdkxevent;
@@ -222,19 +219,19 @@ egg_idletime_x_event_filter (GdkXEvent *gdkxevent, GdkEvent *event, gpointer dat
 
 	alarm_event = (XSyncAlarmNotifyEvent *) xevent;
 
-	alarm = egg_idletime_alarm_find_event (idletime, alarm_event);
-
 	/* did we match one of our alarms? */
+	alarm = egg_idletime_alarm_find_event (idletime, alarm_event);
 	if (alarm != NULL) {
 		/* save the last state we triggered */
 		idletime->priv->last_event = alarm->id;
 
-		/* do the signal */
+		/* are we not the reset symbol */
 		if (alarm->id != 0) {
-			egg_idletime_timeout (idletime, alarm);
+			/* emit signal */
+			g_signal_emit (idletime, signals [SIGNAL_ALARM_EXPIRED], 0, alarm->id);
 
 			/* we need the first alarm to go off to set the reset alarm */
-			egg_idletime_x_set_reset (idletime, alarm_event);
+			egg_idletime_set_reset_alarm (idletime, alarm_event);
 			return GDK_FILTER_CONTINUE;
 		}
 
@@ -245,15 +242,6 @@ egg_idletime_x_event_filter (GdkXEvent *gdkxevent, GdkEvent *event, gpointer dat
 	return GDK_FILTER_CONTINUE;
 }
 
-/**
- * egg_idletime_get_idletime->priv->last_event:
- */
-guint
-egg_idletime_alarm_get (EggIdletime *idletime)
-{
-	return idletime->priv->last_event;
-}
-
 /**
  * egg_idletime_alarm_set:
  */
@@ -262,13 +250,9 @@ egg_idletime_alarm_set (EggIdletime *idletime, guint id, guint timeout)
 {
 	EggIdletimeAlarm *alarm;
 
-	/* id cannot be zero */
-	if (id == 0)
-		return FALSE;
-
-	/* timeout cannot be zero */
-	if (timeout == 0)
-		return FALSE;
+	g_return_val_if_fail (EGG_IS_IDLETIME (idletime), FALSE);
+	g_return_val_if_fail (id != 0, FALSE);
+	g_return_val_if_fail (timeout != 0, FALSE);
 
 	/* see if we already created an alarm with this ID */
 	alarm = egg_idletime_alarm_find_id (idletime, id);
@@ -276,8 +260,9 @@ egg_idletime_alarm_set (EggIdletime *idletime, guint id, guint timeout)
 		/* create a new alarm */
 		alarm = g_new0 (EggIdletimeAlarm, 1);
 
-		/* set the id - this is just something like userdata */
+		/* set the default values */
 		alarm->id = id;
+		alarm->xalarm = None;
 
 		/* add to array */
 		g_ptr_array_add (idletime->priv->array, alarm);
@@ -287,7 +272,7 @@ egg_idletime_alarm_set (EggIdletime *idletime, guint id, guint timeout)
 	XSyncIntToValue (&alarm->timeout, (gint)timeout);
 
 	/* set, and start the timer */
-	egg_idletime_xsync_alarm_set (idletime, alarm, TRUE);
+	egg_idletime_xsync_alarm_set (idletime, alarm, EGG_IDLETIME_ALARM_TYPE_POSITIVE);
 	return TRUE;
 }
 
@@ -297,7 +282,8 @@ egg_idletime_alarm_set (EggIdletime *idletime, guint id, guint timeout)
 static gboolean
 egg_idletime_alarm_free (EggIdletime *idletime, EggIdletimeAlarm *alarm)
 {
-	XSyncDestroyAlarm (idletime->priv->dpy, alarm->xalarm);
+	if (alarm->xalarm)
+		XSyncDestroyAlarm (idletime->priv->dpy, alarm->xalarm);
 	g_free (alarm);
 	g_ptr_array_remove (idletime->priv->array, alarm);
 	return TRUE;
@@ -310,6 +296,9 @@ gboolean
 egg_idletime_alarm_remove (EggIdletime *idletime, guint id)
 {
 	EggIdletimeAlarm *alarm;
+
+	g_return_val_if_fail (EGG_IS_IDLETIME (idletime), FALSE);
+
 	alarm = egg_idletime_alarm_find_id (idletime, id);
 	if (alarm == NULL)
 		return FALSE;
@@ -319,7 +308,6 @@ egg_idletime_alarm_remove (EggIdletime *idletime, guint id)
 
 /**
  * egg_idletime_class_init:
- * @klass: This class instance
  **/
 static void
 egg_idletime_class_init (EggIdletimeClass *klass)
@@ -346,8 +334,6 @@ egg_idletime_class_init (EggIdletimeClass *klass)
 
 /**
  * egg_idletime_init:
- *
- * @egg_idletime: This class instance
  **/
 static void
 egg_idletime_init (EggIdletime *idletime)
@@ -356,7 +342,7 @@ egg_idletime_init (EggIdletime *idletime)
 	int ncounters;
 	XSyncSystemCounter *counters;
 	EggIdletimeAlarm *alarm;
-	int i;
+	guint i;
 
 	idletime->priv = EGG_IDLETIME_GET_PRIVATE (idletime);
 
@@ -375,11 +361,11 @@ egg_idletime_init (EggIdletime *idletime)
 
 	/* gtk_init should do XSyncInitialize for us */
 	counters = XSyncListSystemCounters (idletime->priv->dpy, &ncounters);
-	for (i = 0; i < ncounters && !idletime->priv->idle_counter; i++) {
-		if (!strcmp(counters[i].name, "IDLETIME"))
+	for (i=0; i < ncounters && !idletime->priv->idle_counter; i++) {
+		if (strcmp(counters[i].name, "IDLETIME") == 0)
 			idletime->priv->idle_counter = counters[i].counter;
 	}
-//	XSyncFreeSystemCounterList (counters);
+	XSyncFreeSystemCounterList (counters);
 
 	/* arh. we don't have IDLETIME support */
 	if (!idletime->priv->idle_counter) {
@@ -390,17 +376,17 @@ egg_idletime_init (EggIdletime *idletime)
 	idletime->priv->reset_set = FALSE;
 
 	/* catch the timer alarm */
-	gdk_window_add_filter (NULL, egg_idletime_x_event_filter, idletime);
+	gdk_window_add_filter (NULL, egg_idletime_event_filter_cb, idletime);
 
 	/* create a reset alarm */
 	alarm = g_new0 (EggIdletimeAlarm, 1);
 	alarm->id = 0;
+	alarm->xalarm = None;
 	g_ptr_array_add (idletime->priv->array, alarm);
 }
 
 /**
  * egg_idletime_finalize:
- * @object: This class instance
  **/
 static void
 egg_idletime_finalize (GObject *object)
@@ -415,6 +401,7 @@ egg_idletime_finalize (GObject *object)
 	idletime = EGG_IDLETIME (object);
 	idletime->priv = EGG_IDLETIME_GET_PRIVATE (idletime);
 
+	/* free all counters, including reset counter */
 	for (i=0; i<idletime->priv->array->len; i++) {
 		alarm = g_ptr_array_index (idletime->priv->array, i);
 		egg_idletime_alarm_free (idletime, alarm);
@@ -426,7 +413,6 @@ egg_idletime_finalize (GObject *object)
 
 /**
  * egg_idletime_new:
- * Return value: new EggIdletime instance.
  **/
 EggIdletime *
 egg_idletime_new (void)
@@ -497,7 +483,6 @@ egg_idletime_test (gpointer data)
 {
 	EggIdletime *idletime;
 	gboolean ret;
-	guint alarm;
 	guint i;
 	EggTest *test = (EggTest *) data;
 
@@ -533,11 +518,10 @@ egg_idletime_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check if we are alarm zero with no alarms");
-	alarm = egg_idletime_alarm_get (idletime);
-	if (alarm == 0) {
+	if (idletime->priv->last_event == 0) {
 		egg_test_success (test, NULL);
 	} else {
-		egg_test_failed (test, "alarm %i set!", alarm);
+		egg_test_failed (test, "alarm %i set!", idletime->priv->last_event);
 	}
 
 	/************************************************************/
@@ -593,20 +577,18 @@ egg_idletime_test (gpointer data)
 
 		/************************************************************/
 		egg_test_title (test, "check if correct alarm has gone off");
-		alarm = egg_idletime_alarm_get (idletime);
-		if (alarm == 101) {
+		if (idletime->priv->last_event == 101) {
 			egg_test_success (test, "correct alarm");
 		} else {
-			egg_test_failed (test, "alarm %i set!", alarm);
+			egg_test_failed (test, "alarm %i set!", idletime->priv->last_event);
 		}
 
 		/************************************************************/
 		egg_test_title (test, "check if alarm has gone off in correct time");
-		alarm = egg_idletime_alarm_get (idletime);
 		if (event_time > 3000 && event_time < 6000) {
 			egg_test_success (test, "correct, timeout ideally %ims (we did after %ims)", 5000, event_time);
 		} else {
-			egg_test_failed (test, "alarm %i did not timeout correctly !", alarm);
+			egg_test_failed (test, "alarm %i did not timeout correctly !", idletime->priv->last_event);
 		}
 	}
 
@@ -630,7 +612,6 @@ egg_idletime_test (gpointer data)
 
 	/************************************************************/
 	egg_test_title (test, "check if alarm has gone off in the old time");
-	alarm = egg_idletime_alarm_get (idletime);
 	if (event_time > 5000) {
 		egg_test_success (test, "last timeout value used");
 	} else {
