@@ -58,14 +58,6 @@ typedef struct
 							 gboolean	 low_battery);
 	void		(* power_save_status_changed)	(GpmManager	*manager,
 							 gboolean	 save_power);
-	void		(* can_suspend_changed)		(GpmManager	*manager,
-							 gboolean	 can_suspend);
-	void		(* can_hibernate_changed)	(GpmManager	*manager,
-							 gboolean	 can_hibernate);
-	void		(* can_shutdown_changed)	(GpmManager	*manager,
-							 gboolean	 can_shutdown);
-	void		(* can_reboot_changed)		(GpmManager	*manager,
-							 gboolean	 can_reboot);
 } GpmManagerClass;
 
 typedef enum
@@ -94,10 +86,6 @@ gboolean	 gpm_manager_suspend			(GpmManager	*manager,
 							 GError		**error);
 gboolean	 gpm_manager_hibernate			(GpmManager	*manager,
 							 GError		**error);
-gboolean	 gpm_manager_reboot			(GpmManager	*manager,
-							 GError		**error);
-gboolean	 gpm_manager_shutdown			(GpmManager	*manager,
-							 GError		**error);
 gboolean	 gpm_manager_can_suspend		(GpmManager	*manager,
 							 gboolean	*can_suspend,
 							 GError		**error);
