@@ -32,24 +32,23 @@
 #include "egg-debug.h"
 #include "egg-dbus-proxy.h"
 
-static void     gpm_screensaver_class_init (GpmScreensaverClass *klass);
-static void     gpm_screensaver_init       (GpmScreensaver      *screensaver);
 static void     gpm_screensaver_finalize   (GObject		*object);
 
 #define GPM_SCREENSAVER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_SCREENSAVER, GpmScreensaverPrivate))
 
+#define GS_LISTENER_SERVICE	"org.gnome.ScreenSaver"
+#define GS_LISTENER_PATH	"/org/gnome/ScreenSaver"
+#define GS_LISTENER_INTERFACE	"org.gnome.ScreenSaver"
+
 struct GpmScreensaverPrivate
 {
 	EggDbusProxy		*gproxy;
 	GConfClient		*conf;
-	guint			 idle_delay;	/* the setting in g-s-p, cached */
 };
 
 enum {
 	GS_DELAY_CHANGED,
 	CONNECTION_CHANGED,
-	SESSION_IDLE_CHANGED,
-	POWERSAVE_IDLE_CHANGED,
 	AUTH_REQUEST,
 	LAST_SIGNAL
 };
@@ -81,29 +80,6 @@ gpm_screensaver_auth_end (DBusGProxy     *proxy,
 	g_signal_emit (screensaver, signals [AUTH_REQUEST], 0, FALSE);
 }
 
-/** Invoked when we get the AuthenticationRequestEnd from g-s when the user
- *  has entered a valid password or re-authenticated.
- */
-static void
-gpm_screensaver_session_idle_changed (DBusGProxy     *proxy,
-			      gboolean        is_idle,
-			      GpmScreensaver *screensaver)
-{
-	egg_debug ("emitting session-idle-changed : (%i)", is_idle);
-	g_signal_emit (screensaver, signals [SESSION_IDLE_CHANGED], 0, is_idle);
-}
-
-/** Invoked after a short delay
- */
-static void
-gpm_screensaver_powersave_idle_changed (DBusGProxy     *proxy,
-			                gboolean        is_idle,
-			                GpmScreensaver *screensaver)
-{
-	egg_debug ("emitting powersave-idle-changed : (%i)", is_idle);
-	g_signal_emit (screensaver, signals [POWERSAVE_IDLE_CHANGED], 0, is_idle);
-}
-
 /**
  * gpm_screensaver_proxy_connect_more:
  * @screensaver: This class instance
@@ -137,20 +113,6 @@ gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
 				     G_CALLBACK (gpm_screensaver_auth_end),
 				     screensaver, NULL);
 
-	/* get SessionIdleChanged */
-	dbus_g_proxy_add_signal (proxy, "SessionIdleChanged", G_TYPE_BOOLEAN, G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (proxy,
-				     "SessionIdleChanged",
-				     G_CALLBACK (gpm_screensaver_session_idle_changed),
-				     screensaver, NULL);
-
-	/* get SessionIdleChanged */
-	dbus_g_proxy_add_signal (proxy, "SessionPowerManagementIdleChanged", G_TYPE_BOOLEAN, G_TYPE_INVALID);
-	dbus_g_proxy_connect_signal (proxy,
-				     "SessionPowerManagementIdleChanged",
-				     G_CALLBACK (gpm_screensaver_powersave_idle_changed),
-				     screensaver, NULL);
-
 	return TRUE;
 }
 
@@ -168,27 +130,6 @@ gpm_screensaver_proxy_disconnect_more (GpmScreensaver *screensaver)
 	return TRUE;
 }
 
-/**
- * gpm_conf_gconf_key_changed_cb:
- *
- * We might have to do things when the gconf keys change; do them here.
- **/
-static void
-gpm_conf_gconf_key_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, GpmScreensaver *screensaver)
-{
-	GConfValue *value;
-
-	value = gconf_entry_get_value (entry);
-	if (value == NULL)
-		return;
-
-	if (strcmp (entry->key, GS_PREF_IDLE_DELAY) == 0) {
-		screensaver->priv->idle_delay = gconf_value_get_int (value);
-		egg_debug ("emitting gs-delay-changed : %i", screensaver->priv->idle_delay);
-		g_signal_emit (screensaver, signals [GS_DELAY_CHANGED], 0, screensaver->priv->idle_delay);
-	}
-}
-
 /**
  * gpm_screensaver_lock_enabled:
  * @screensaver: This class instance
@@ -218,18 +159,6 @@ gpm_screensaver_lock_set (GpmScreensaver *screensaver, gboolean lock)
 	return TRUE;
 }
 
-/**
- * gpm_screensaver_get_delay:
- * @screensaver: This class instance
- * Return value: The delay for the idle time set in gnome-screesaver-properties.
- **/
-gint
-gpm_screensaver_get_delay (GpmScreensaver *screensaver)
-{
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), 0);
-	return screensaver->priv->idle_delay;
-}
-
 /**
  * gpm_screensaver_lock
  * @screensaver: This class instance
@@ -416,45 +345,6 @@ gpm_screensaver_poke (GpmScreensaver *screensaver)
 	return TRUE;
 }
 
-/**
- * gpm_screensaver_get_idle:
- * @screensaver: This class instance
- * @time_secs: The returned idle time, passed by ref
- * Return value: Success value.
- **/
-gboolean
-gpm_screensaver_get_idle (GpmScreensaver *screensaver, gint *time_secs)
-{
-	GError *error = NULL;
-	gboolean ret = TRUE;
-	DBusGProxy *proxy;
-
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
-	g_return_val_if_fail (time != NULL, FALSE);
-
-	proxy = egg_dbus_proxy_get_proxy (screensaver->priv->gproxy);
-	if (proxy == NULL) {
-		egg_warning ("not connected");
-		return FALSE;
-	}
-
-	ret = dbus_g_proxy_call (proxy, "GetActiveTime", &error,
-				 G_TYPE_INVALID,
-				 G_TYPE_UINT, time_secs,
-				 G_TYPE_INVALID);
-	if (error) {
-		egg_debug ("ERROR: %s", error->message);
-		g_error_free (error);
-	}
-	if (!ret) {
-		/* abort as the DBUS method failed */
-		egg_warning ("GetActiveTime failed!");
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
 /**
  * gpm_screensaver_class_init:
  * @klass: This class instance
@@ -495,25 +385,6 @@ gpm_screensaver_class_init (GpmScreensaverClass *klass)
 			      NULL,
 			      g_cclosure_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
-
-	signals [SESSION_IDLE_CHANGED] =
-		g_signal_new ("session-idle-changed",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, session_idle_changed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
-			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
-	signals [POWERSAVE_IDLE_CHANGED] =
-		g_signal_new ("powersave-idle-changed",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, session_idle_changed),
-			      NULL,
-			      NULL,
-			      g_cclosure_marshal_VOID__BOOLEAN,
-			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 }
 
 /**
@@ -560,16 +431,6 @@ gpm_screensaver_init (GpmScreensaver *screensaver)
 	gpm_screensaver_proxy_connect_more (screensaver);
 
 	screensaver->priv->conf = gconf_client_get_default ();
-
-	/* watch gnome-screensaver keys */
-	gconf_client_add_dir (screensaver->priv->conf, GS_CONF_DIR,
-			      GCONF_CLIENT_PRELOAD_NONE, NULL);
-	gconf_client_notify_add (screensaver->priv->conf, GS_CONF_DIR,
-				 (GConfClientNotifyFunc) gpm_conf_gconf_key_changed_cb,
-				 screensaver, NULL, NULL);
-
-	/* get value of delay in g-s-p */
-	screensaver->priv->idle_delay = gconf_client_get_int (screensaver->priv->conf, GS_PREF_IDLE_DELAY, NULL);
 }
 
 /**
