@@ -355,7 +355,9 @@ static void
 gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
 {
 	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
-	egg_debug ("clear tray (icon = %p)", icon);
+	egg_debug ("clear tray");
+	g_object_ref_sink (widget);
+	g_object_unref (widget);
 }
 
 /**
